close all; clc; clear all;

%% Algorithm inputs: variable names are generally coherent with article [1]. Corresponding names from PCL code are mentioned in comments.
%  [1] Zhang, K., Chen, S. C., Whitman, D., Shyu, M. L., Yan, J., & Zhang, C. (2003). 
%      A progressive morphological filter for removing nonground measurements from airborne LIDAR data. 
% 	   IEEE transactions on geoscience and remote sensing, 41(4), 872-882.

w_max = 20; %PCL: max_window_size 4
dh_0 = 0.5; %PCL: initial_distance_ 7
dh_max = inf; %PCL: max_distance_ 8
% PCL implementation inputs (default):
b = 2; %PCL: base_ 3
exponential_ = true(1); %PCL: exponential_ 5
c = 1; %PCL: cell_size_ 2
s = 0.3; %PCL: slope_ 6
do_global_thresholding = true(1); % hard coded as true in PCL

%% Load cloud: the point cloud used here is from http://www2.isprs.org/commissions/comm3/wg4/3d-semantic-labeling.html
load('Vaihingen_subsampled.mat'); % xyz array: N X 3 (N is the number of points in the cloud)
pc = airborneCloude;

%% perform PMF
is_ground = PMF( pc, do_global_thresholding, exponential_, w_max,  dh_0, dh_max, b, c, s);
groundCloud = pointCloud(pc.Location(is_ground,:));
notgroundCloud = pointCloud(pc.Location(not(is_ground),:));

%% show segmented cloud
figure; pcshowpair(groundCloud, notgroundCloud); title('segmented cloud')